Changelog
=========

The changelog for the skeleton module is the list of `closed pull requests
<https://github.com/epics-containers/python3-pip-skeleton/pulls?q=is%3Apr+is%3Aclosed>`_

All developments for the ``skeleton`` branch take place via pull requests, and
changes to the commandline tools and docs are not tracked in a changelog.
